@@ -36,12 +36,12 @@ x.use <- x[,1:200]
 ## Ridge projection ##
 ######################
 
-fit.ridge  <- ridge.proj(x = x.use, y = y)
-fit.ridge1 <- ridge.proj(x = x.use + 10^-16, y = y)
+fit.ridge  <- ridge.proj(x = x.use, y = y, betainit = "scaled lasso")
+fit.ridge1 <- ridge.proj(x = x.use + 10^-16, y = y, betainit = "scaled lasso")
 stopifnot(all.equal(fit.ridge$pval, fit.ridge1$pval))
 
 ## Check standardization
-fit.ridge2 <- ridge.proj(x = 2 + 4 * x.use, y = y)
+fit.ridge2 <- ridge.proj(x = 2 + 4 * x.use, y = y, betainit = "scaled lasso")
 stopifnot(all.equal(fit.ridge$pval, fit.ridge2$pval))
 
 stopifnot(all.equal(max(abs(range(fit.ridge$bhat / fit.ridge2$bhat - 4))), 0))
@@ -53,6 +53,7 @@ ci.ridge2 <- confint(fit.ridge2, level = 0.95)
 stopifnot(all.equal(ci.ridge, ci.ridge2 * 4))
 
 
+
 #########
 ## GLM ##
 #########
